@@ -2,7 +2,7 @@
  * main.c - a commandline frontend for the barcode library
  *
  * Copyright (c) 1999 Michele Comitini (mcm@glisco.it)
- * Copyright (c) 1999 Alessandro Rubini (rubini@prosa.it)
+ * Copyright (c) 1999 Alessandro Rubini (rubini@gnu.org)
  * Copyright (c) 1999 Prosa Srl. (prosa@prosa.it)
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -60,6 +60,8 @@ struct {
     {"code128c", BARCODE_128C},
     {"128b",     BARCODE_128B},
     {"code128b", BARCODE_128B},
+    {"128",      BARCODE_128},
+    {"code128",  BARCODE_128},
     {"i25",      BARCODE_I25},
     {"interleaved 2 of 5", BARCODE_I25},
     {NULL, 0}
@@ -219,7 +221,7 @@ int get_geometry(void *arg)
     code_width  = w * unit;
     code_height = h * unit;
     xmargin0 = x * unit;
-    ymargin1 = y * unit;
+    ymargin0 = y * unit;
     return 0;
 }
 
@@ -314,9 +316,9 @@ int get_page_geometry(void *arg)
 	page_wid = dpw * unit;
 	page_hei = dph * unit;
 	if (unit != 1.0) { /* rebuild the page name */
-	    page_name = malloc(16);
-	    if (page_name) snprintf(page_name, 16, "%dx%d\n",
-				    page_wid, page_hei);
+	    page_name = malloc(32); /* big, to avoid snprintf, missing on HP */
+	    if (page_name)
+		sprintf(page_name, "%dx%d\n", page_wid, page_hei);
 	}
 	return 0;
     }
